@@ -86,7 +86,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55600
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -253,6 +253,12 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_87(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_87(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -319,7 +325,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -329,7 +335,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55600
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -486,6 +492,12 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55700
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_87(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_87(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
